window.daikinportal = window.daikinportal || {};

(function (slideshowWidget) {
    var slideshows = [];

    /** The name of the data- HTML attribute that holds the slideshow GUID. */
    slideshowWidget.slideshowGuidAttribute = "data-slideshow-guid";

    /**
     * Adds a Slideshow object to an internal dictionary.
     * @param {string} id The ID of the Slideshow object.
     * @param {object} slideshow The Slideshow object to add.
     */
    slideshowWidget.addSlideshow = function (id, slideshow) {
        var found = window.daikinportal.slideshowWidget.getSlideshow(id);

        if (!found) {
            var slideshowToAdd = {
                id: id,
                slideshow: slideshow
            };

            slideshows.push(slideshowToAdd);
        }
    };

    /**
     * Retrieves a Slideshow object from an internal dictionary by its ID.
     * @param {string} id The ID to search by.
     * @returns {object} Either the found Slideshow object, or null.
     */
    slideshowWidget.getSlideshow = function (id) {
        var found = slideshows.filter(function (currentSlideshow) {
            return currentSlideshow.id === id;
        });

        if (found.length > 0) {
            return found[0];
        } else {
            return null;
        }
    };

    /**
     * Removes a Slideshow object form an internal dictionary.
     * @param {string} id The ID to search by.
     */
    slideshowWidget.removeSlideshow = function (id) {
        for (var i = slideshows.length - 1; i >= 0; i--) {
            if (slideshows[i].id === id) {
                slideshows.splice(i, 1);
            }
        }
    };

    /**
     * Initializes a new Slideshow object in the page.
     * @param {string} slideshowId The ID of the future Slideshow object.
     * @param {bool} editMode Indication of whether the Xperience page builder is in edit mode.
     * @param {number} transitionDelay An interval of the transition to another slide (milliseconds).
     * @param {any} transitionSpeed The duration of each transition (milliseconds).
     */
    slideshowWidget.initSlideshow = function (slideshowId, editMode, useStackedImages, transitionDelay, transitionSpeed) {
        var slideshowselector = "#" + slideshowId;

        var configuration = {
            loop: !editMode,
            speed: transitionSpeed,
            navigation: {
                nextEl: "#" + slideshowId + " .swiper-button-next",
                prevEl: "#" + slideshowId + " .swiper-button-prev"
            },
            effect: "fade",
            fadeEffect: {
                crossFade: true
            },
            autoHeight: true, 
            pagination: {
                el: '.swiper-pagination',
            },
        };

        if (!editMode) {
            configuration["autoplay"] = {
                delay: transitionDelay,
                disableOnInteraction: true
            };
        }

        var slideshow = {};

        if (useStackedImages) {
            slideshow = new stackedCards({
                selector: slideshowselector, //'.mycards',
                layout: "slide",
                transformOrigin: "center",
            });

            slideshow.init();
        } else {
            slideshow = new Swiper(slideshowselector, configuration);
            var download = document.getElementById(`btn-${slideshowId}`);
            if (download) {
                download.addEventListener("click", () => {
                    var editor = document.getElementById(slideshowId);
                    var imageEle = editor.querySelectorAll('img.responsive-img');
                    let set = new Set();
                    imageEle.forEach(x => {
                        set.add(x.getAttribute('src'));
                    });
                    const imgLinks = Array.from(set);

                    var zip = new JSZip();
                    var count = imgLinks.length;
                    for (var i = 0; i < imgLinks.length; i++) {
                        const imagePath = imgLinks[i];
                        const fileName = imagePath.substr(imagePath.lastIndexOf("/") + 1)
                        JSZipUtils.getBinaryContent(imagePath, {
                            progress: (event) => {
                                console.log(event.percent + "% of " + event.path + " loaded")
                            },
                            callback: (err, data) => {
                                count--;
                                if (err) {
                                    console.error(err);
                                }

                                zip.file(fileName, data, { binary: true });
                                if (count == 0) {
                                    zip.generateAsync({ type: "blob" }).then(function (content) {
                                        // see FileSaver.js
                                        saveAs(content, "download.zip");
                                    });
                                }
                            }
                        });
                    }
                });
            }
        }

        window.daikinportal.slideshowWidget.addSlideshow(slideshowId, slideshow);
    };

    /**
     * Gets a Slideshow object for a given slideshow inline editor instance.
     * @param {HTMLElement} editor The HTML element of the inline editor.
     * @param {string} slideshowGuidAttribute The name of the data- HTML attribute containing the Slideshow ID.
     * @returns {object} The Slideshow object.
     */
    slideshowWidget.getCurrentSlideshow = function (editor, slideshowGuidAttribute) {
        // Retrieving via the "slideshow" property of the respective HTML element
        //return editor.parentElement.slideshow;

        // Retrieving off of the global namespace container
        return window.daikinportal.slideshowWidget.getSlideshow(editor.getAttribute(slideshowGuidAttribute)).slideshow;
    };

    /**
     * Removes any prefixes that had been previously concatedated in front of a GUID.
     * @param {string} id The GUID with the prefix.
     * @returns {string} The bare GUID value.
     */
    slideshowWidget.getGuidFromId = function (id) {
        return id.slice(-36);
    };

    /**
     * Gets an array of Dropzone HTML element IDs of a given Slideshow object.
     * @param {object} slideshow The parent Slideshow object.
     * @returns {string[]} The array of Dropzone IDs.
     */
    slideshowWidget.collectImageIds = function (slideshow) {
        var output = [];

        for (var s = 0; s <= slideshow.slides.length - 1; s++) {
            var childElement = slideshow.slides[s].children[0];
            output.push(childElement.id);
        }

        return output;
    };
}(window.daikinportal.slideshowWidget = window.daikinportal.slideshowWidget || {}));
